@@ -225,10 +225,20 @@ class basics:
     def _convert_time(self, time):
         """Converts time object to ``datetime.datetime`` object"""
         try:
-            return pd.to_datetime(
+            time_index = pd.to_datetime(
                 time.indexes["time"].astype("str"),
                 format=time.units.split(" ")[-1],
-            )
+            ).round("s")
+            cf_datetime = [
+                cftime.datetime(
+                    t.year,
+                    t.month,
+                    t.day,
+                    calendar=time.calendar,
+                )
+                for t in time_index
+            ]
+            return xr.CFTimeIndex(cf_datetime)
         except Exception:
             return time.indexes["time"]
 
